#!/usr/bin/env python
import sys

import eel
from loguru import logger

from controllers.ControllerADC import ControllerADC
from controllers.ControllerChromium import ControllerChromium
from models.LogSeverity import LogSeverity

logger.add(sys.stdout, level='DEBUG', format="<g>{time}</> | <r>{level}</> | <lvl>{message}</>")
logger.add('logs/{time:YYYY-MM-DD}.log', level='DEBUG', rotation='00:00', retention='10 days')
logger.info('started')

@eel.expose
def update_state_backend(project_json):
    return ControllerChromium.instance().from_json(project_json)

@eel.expose
def initialize():
    return ControllerChromium.instance().update_state_frontend()

@eel.expose
def open_filepath_txt():
    return ControllerChromium.instance().open_filepath_txt()

@eel.expose
def open_filepath_ply():
    return ControllerChromium.instance().open_filepath_ply()

@eel.expose
def load_ply_and_txt():
    return ControllerChromium.instance().load_ply_and_txt()

@eel.expose
def save_project():
    return ControllerChromium.instance().save_project()

@eel.expose
def save_as_project():
    return ControllerChromium.instance().save_as_project()

@eel.expose
def open_project():
    return ControllerChromium.instance().open_project()

@eel.expose
def add_log(
    timestamp_unix: int,
    source: str,
    severity: str,
    message: str
):
    timestamp_unix = int(timestamp_unix)
    timestamp_unix /= 1000
    timestamp_unix = int(timestamp_unix)
    severity = LogSeverity(severity)
    ControllerChromium.instance().add_log(timestamp_unix, source, severity, message)

@eel.expose
def save_poi(poi_name, x, y):
    return ControllerChromium.instance().save_poi(poi_name, x, y)

@eel.expose
def change_poi(poi_name, x, y):
    return ControllerChromium.instance().change_poi(poi_name, x, y)

@eel.expose
def delete_poi(poi_name):
    return ControllerChromium.instance().delete_poi(poi_name)

@eel.expose
def adc_take_off():
    return ControllerADC.instance().take_off()

@eel.expose
def adc_land():
    return ControllerADC.instance().land()

@eel.expose
def adc_stop():
    return ControllerADC.instance().stop()

@eel.expose
def clear_all_poi():
    return ControllerChromium.instance().clear_all_poi()

@eel.expose
def adc_fly_to_poi(poi_name, x, y):
    x, y = ControllerChromium.instance().convert_x_y_to_original(x, y)
    return ControllerADC.instance().fly_to_poi(
        x, y, z=0, w=0, name_poi=poi_name
    )

@eel.expose
def adc_yaw(degrees):
    return ControllerADC.instance().yaw(degrees)


eel.start(
    'index.html',
    port=8880,
    size=(ControllerChromium.instance().screen_width, ControllerChromium.instance().screen_height),
    position=(0, 0),
    js_result_timeout=0
)
