class DialogMain extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            project: false,
            isDialogLoadPLYandTXT: false
        };

        this.active_poi = false;
        this.active_poi_name = "";
        this.refMap = null;

        document.addEventListener(UPDATE_STATE_FRONTEND, this.updateStateFrontend);
        $(window).resize(this.onWindowResize)
    }

    onWindowResize = (event) => {
        if(this.refMap) {
            this.refMap.onResize();
        }
    }

    updateStateFrontend = (event) => {
        try {
            this.setState({
                project: event.detail
            });
        } catch (e) {
            alert(e.message);
        }
    }

    componentDidMount = () => {
        eel.initialize();
    }

    onAdcTakeOff = () => {
        eel.adc_take_off()
    }

    onAdcLand = () => {
        eel.adc_land()
    }

    onAdcYawLeft = () => {
        let angle = prompt('Enter angle in degrees to yaw left:')
        eel.adc_yaw(-angle);
    }

    onAdcYawRight = () => {
        let angle = prompt('Enter angle in degrees to yaw right:')
        eel.adc_yaw(angle);
    }

    onAdcStopAll = () => {
        eel.adc_stop()
    }



    render = () => {
        if (!this.state.project) {
            return (<div></div>); //before loading
        }

        return (<div className="panels">
            <div className="panel-main">
                <div id="panel-menu-bar">
                    <ComponentMenu
                        onDialogLoadPLYandTXT={() => {
                            this.setState({isDialogLoadPLYandTXT: true});
                        }}
                    />
                </div>
                <div id="panel-main-plot">
                    <ComponentMap
                        ref={(ref) => this.refMap = ref}
                        project={this.state.project}
                        onChangePOI={(active_poi, active_poi_name) => {
                            this.active_poi = active_poi;
                            this.active_poi_name = active_poi_name;
                            eel.change_poi(this.active_poi_name, this.active_poi.x, this.active_poi.y)
                        }}
                    />
                </div>
                <ComponentPanelLogs
                    logs={this.state.project.logs.logs}
                    isOpened={true}
                    onTogglePanel={() => {
                        if (this.refMap) {
                            this.refMap.onResize();
                        }
                    }}
                />
                <ComponentPanelStatusBottom />
            </div>
            <div className="panel-left">
                <div id="panel-left-scrollable">
                    <div className="panel-logo"></div>
                    <ComponentPanelSide title="Layers" isOpened={true}>
                        <FormControlLabel
                            control={<Checkbox
                                checked={this.state.project.view_settings.is_layer_pointcloud_raw}
                                onChange={(event) => {
                                    this.state.project.view_settings.is_layer_pointcloud_raw = event.target.checked;
                                    this.setState({
                                        project: {...this.state.project}
                                    });
                                }}
                            />}
                            label="Raw pointcloud"/><br/>
                        <FormControlLabel
                            control={<Checkbox
                                checked={this.state.project.view_settings.is_layer_pointcloud_filtered}
                                onChange={(event) => {
                                    this.state.project.view_settings.is_layer_pointcloud_filtered = event.target.checked;
                                    this.setState({
                                        project: {...this.state.project}
                                    });
                                }}
                            />}
                            label="Filtered pointcloud"/><br/>
                        <FormControlLabel
                            control={<Checkbox
                                checked={this.state.project.view_settings.is_layer_walls}
                                onChange={(event) => {
                                    this.state.project.view_settings.is_layer_walls = event.target.checked;
                                    this.setState({
                                        project: {...this.state.project}
                                    });
                                }}
                            />}
                            label="Walls"/><br/>
                        <FormControlLabel
                            control={<Checkbox
                                checked={this.state.project.view_settings.is_layer_flight_path}
                                onChange={(event) => {
                                    this.state.project.view_settings.is_layer_flight_path = event.target.checked;
                                    this.setState({
                                        project: {...this.state.project}
                                    });
                                }}
                            />}
                            label="Flight path"/><br/>
                        <FormControlLabel
                            control={<Checkbox
                                checked={this.state.project.view_settings.is_layer_poi}
                                onChange={(event) => {
                                    this.state.project.view_settings.is_layer_poi = event.target.checked;
                                    if (!this.state.project.view_settings.is_layer_poi) {
                                        this.state.project.view_settings.is_snap_to_flight_path_poi = false;
                                    }
                                    this.setState({
                                        project: {...this.state.project}
                                    });
                                }}
                            />}
                            label="Points of interest"/>
                    </ComponentPanelSide>
                    <ComponentPanelSide title="Points of interest" isOpened={true}>
                        <ComponentPanelPOIs
                            isSnapToFlightPath={this.state.project.view_settings.is_snap_to_flight_path_poi}
                            onSnapToFlightPathChange={(event) => {
                                this.state.project.view_settings.is_snap_to_flight_path_poi = event.target.checked;
                                if (this.state.project.view_settings.is_snap_to_flight_path_poi) {
                                    this.state.project.view_settings.is_layer_flight_path = true;
                                }
                                this.setState({
                                    project: {...this.state.project}
                                });
                            }}
                        />
                    </ComponentPanelSide>
                    <ComponentPanelSide title="Status" isOpened={true}>
                        <ComponentPanelStatusSide />
                    </ComponentPanelSide>
                </div>
                <div id="panel-left-bottom">
                    <div className="row-buttons">
                        <Button variant="contained" style={{marginBottom: 10}} onClick={this.onAdcTakeOff}>Take
                            off</Button>
                        <Button variant="contained" style={{marginBottom: 10}} onClick={this.onAdcLand}>Land</Button>
                    </div>
                    <div className="clear"/>
                    <div className="row-buttons">
                        <Button variant="contained" style={{marginBottom: 10}} onClick={this.onAdcYawLeft}>Yaw
                            left</Button>
                        <Button variant="contained" style={{marginBottom: 10}} onClick={this.onAdcYawRight}>Yaw
                            right</Button>
                    </div>
                    <div className="clear"/>
                    <Button id="button-stop-all" variant="contained" style={{marginBottom: 10}}
                            onClick={this.onAdcStopAll}>Stop current action</Button>
                </div>
            </div>
            <DialogLoadPLYandTXT isOpen={this.state.isDialogLoadPLYandTXT} onClose={() => {
                this.setState({isDialogLoadPLYandTXT: false});
            }}/>
        </div>);
    }
}


